# <Palace Name>

<!-- One sentence: what this palace covers and who/what it belongs to. -->
<One sentence describing the scope of this palace.>

## Global Rooms

<!-- Rooms shared across all projects. Remove this section if none exist yet. -->

| Room | Description | Path |
|---|---|---|
| `<room-name>` | <What knowledge lives here, present tense> | `global/<room-name>/` |

## Project Rooms

<!-- One row per project. Description should state what domain facts live here. -->

| Room | Description | Path |
|---|---|---|
| `<project-name>` | <What knowledge lives here, present tense> | `projects/<project-name>/` |

---
_Last consolidated: YYYY-MM-DD_

<!--
NAVIGATION: Read this file first. Identify the relevant room(s), then read
only those. Do not load the full palace. If no room matches your query,
check whether a new room is warranted before writing to an existing one.

SIZE LIMIT: Keep this file under 50 lines. If the palace outgrows this
budget, introduce sub-indices: global/INDEX.md and projects/<name>/INDEX.md,
with this root INDEX.md pointing to them instead of individual rooms.
-->
